==> mozilla-headless-services_0.1.0.0~20090731.orig.tar.gz: mozilla-headless-services-0.1.0~20090731/mhs/mhs-service.h <==
/* mhs: A GObject wrapper for the Mozilla Mhs API
 *
 * Copyright (C) 2009  Intel Corporation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __MHS_SERVICE_H__
#define __MHS_SERVICE_H__

#include <glib.h>

G_BEGIN_DECLS

#define MHS_SERVICE_HISTORY           "org.moblin.mhs.History"
#define MHS_SERVICE_HISTORY_PATH      "/org/moblin/mhs/History"
#define MHS_SERVICE_HISTORY_INTERFACE "org.moblin.mhs.History"

#define MHS_SERVICE_PREFS             "org.moblin.mhs.Prefs"
#define MHS_SERVICE_PREFS_PATH        "/org/moblin/mhs/Prefs"
#define MHS_SERVICE_PREFS_INTERFACE   "org.moblin.mhs.Prefs"

#define MHS_SERVICE_COOKIES           "org.moblin.mhs.Cookies"
#define MHS_SERVICE_COOKIES_PATH      "/org/moblin/mhs/Cookies"
#define MHS_SERVICE_COOKIES_INTERFACE "org.moblin.mhs.Cookies"

#define MHS_SERVICE_LOGIN_MANAGER_STORAGE           \
                                      "org.moblin.mhs.LoginManagerStorage"
#define MHS_SERVICE_LOGIN_MANAGER_STORAGE_PATH      \
                                      "/org/moblin/mhs/LoginManagerStorage"
#define MHS_SERVICE_LOGIN_MANAGER_STORAGE_INTERFACE \
                                      "org.moblin.mhs.LoginManagerStorage"

G_END_DECLS

#endif /* __MHS_SERVICE_H__ */

==> mozilla-headless-services_0.10.4.orig.tar.gz: mozilla-headless-services-0.10.4.orig/mhs/mhs-service.h <==
/* mhs: A GObject wrapper for the Mozilla Mhs API
 *
 * Copyright (C) 2009  Intel Corporation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __MHS_SERVICE_H__
#define __MHS_SERVICE_H__

#include <glib.h>

G_BEGIN_DECLS

#define MHS_SERVICE_HISTORY           "org.moblin.mhs.History"
#define MHS_SERVICE_HISTORY_PATH      "/org/moblin/mhs/History"
#define MHS_SERVICE_HISTORY_INTERFACE "org.moblin.mhs.History"

#define MHS_SERVICE_PREFS             "org.moblin.mhs.Prefs"
#define MHS_SERVICE_PREFS_PATH        "/org/moblin/mhs/Prefs"
#define MHS_SERVICE_PREFS_INTERFACE   "org.moblin.mhs.Prefs"

#define MHS_SERVICE_COOKIES           "org.moblin.mhs.Cookies"
#define MHS_SERVICE_COOKIES_PATH      "/org/moblin/mhs/Cookies"
#define MHS_SERVICE_COOKIES_INTERFACE "org.moblin.mhs.Cookies"

#define MHS_SERVICE_LOGIN_MANAGER_STORAGE           \
                                      "org.moblin.mhs.LoginManagerStorage"
#define MHS_SERVICE_LOGIN_MANAGER_STORAGE_PATH      \
                                      "/org/moblin/mhs/LoginManagerStorage"
#define MHS_SERVICE_LOGIN_MANAGER_STORAGE_INTERFACE \
                                      "org.moblin.mhs.LoginManagerStorage"

#define MHS_SERVICE_PERMISSION_MANAGER \
                                      "org.moblin.mhs.PermissionManager"
#define MHS_SERVICE_PERMISSION_MANAGER_PATH \
                                      "/org/moblin/mhs/PermissionManager"
#define MHS_SERVICE_PERMISSION_MANAGER_INTERFACE \
                                      "org.moblin.mhs.PermissionManager"

G_END_DECLS

#endif /* __MHS_SERVICE_H__ */
